@@ -651,7 +651,7 @@ class Traits(Record):
       running on. If the system is behind a NAT, this may differ from the IP
       address locally assigned to it.
 
-      :type: str
+      :type: ipaddress.IPv4Address or ipaddress.IPv6Address
 
     .. attribute:: is_anonymous
 
@@ -843,7 +843,7 @@ class Traits(Record):
     autonomous_system_organization: Optional[str]
     connection_type: Optional[str]
     domain: Optional[str]
-    _ip_address: IPAddress
+    _ip_address: Optional[IPAddress]
     is_anonymous: bool
     is_anonymous_proxy: bool
     is_anonymous_vpn: bool
@@ -914,8 +914,6 @@ class Traits(Record):
         self.static_ip_score = static_ip_score
         self.user_type = user_type
         self.user_count = user_count
-        if ip_address is None:
-            raise TypeError("ip_address must be defined")
         self._ip_address = ip_address
         if network is None:
             self._network = None
@@ -927,11 +925,16 @@ class Traits(Record):
         self._prefix_len = prefix_len
 
     @property
-    def ip_address(self) -> Union[IPv4Address, IPv6Address]:
+    def ip_address(self) -> Optional[Union[IPv4Address, IPv6Address]]:
         """The IP address for the record."""
-        if not isinstance(self._ip_address, (IPv4Address, IPv6Address)):
-            self._ip_address = ipaddress.ip_address(self._ip_address)
-        return self._ip_address
+        ip_address = self._ip_address
+        if ip_address is None:
+            return None
+
+        if not isinstance(ip_address, (IPv4Address, IPv6Address)):
+            ip_address = ipaddress.ip_address(ip_address)
+            self._ip_address = ip_address
+        return ip_address
 
     @property
     def network(self) -> Optional[Union[ipaddress.IPv4Network, ipaddress.IPv6Network]]:
